from setuptools import setup

setup(name='gb_prob_dist',
      version='0.1',
      description='Gaussian and Binomial Probability Distributions',
      packages=['gb_prob_dist'],
      author='Depei Zhang',
      author_email='dpz.zhang@gmail.com',
      zip_safe=False)
